( cd lib ; rm -rf libcap.so.2 )
( cd lib ; ln -sf libcap.so.2.20 libcap.so.2 )
( cd lib ; rm -rf libsysfs.so.2 )
( cd lib ; ln -sf libsysfs.so.2.0.1 libsysfs.so.2 )
( cd lib ; rm -rf libfuse.so )
( cd lib ; ln -sf libfuse.so.2.8.5 libfuse.so )
( cd lib ; rm -rf libgcc_s.so.1 )
( cd lib ; ln -sf ../usr/lib/libgcc_s.so.1 libgcc_s.so.1 )
( cd lib ; rm -rf libacl.so.1 )
( cd lib ; ln -sf libacl.so.1.1.0 libacl.so.1 )
( cd lib ; rm -rf libdm.so.0 )
( cd lib ; ln -sf libdm.so.0.0.4 libdm.so.0 )
( cd lib ; rm -rf libcap.so )
( cd lib ; ln -sf libcap.so.2 libcap.so )
( cd lib ; rm -rf libtermcap.so.2 )
( cd lib ; ln -sf libtermcap.so.2.0.8 libtermcap.so.2 )
( cd lib ; rm -rf libattr.so.1 )
( cd lib ; ln -sf libattr.so.1.1.0 libattr.so.1 )
( cd lib ; rm -rf libncurses.so.5 )
( cd lib ; ln -sf libncurses.so.5.9 libncurses.so.5 )
( cd lib ; rm -rf libfuse.so.2 )
( cd lib ; ln -sf libfuse.so.2.8.5 libfuse.so.2 )
( cd lib ; rm -rf libbz2.so.1 )
( cd lib ; ln -sf libbz2.so.1.0 libbz2.so.1 )
( cd lib ; rm -rf libpopt.so.0 )
( cd lib ; ln -sf libpopt.so.0.0.0 libpopt.so.0 )
( cd lib ; rm -rf libgpm.so.2 )
( cd lib ; ln -sf libgpm.so.2.0.0 libgpm.so.2 )
( cd lib ; rm -rf libbz2.so.1.0 )
( cd lib ; ln -sf libbz2.so.1.0.6 libbz2.so.1.0 )
( cd lib ; rm -rf libncursesw.so.5 )
( cd lib ; ln -sf libncursesw.so.5.9 libncursesw.so.5 )
( cd lib ; rm -rf libgcc_s.so )
( cd lib ; ln -sf ../usr/lib/libgcc_s.so libgcc_s.so )
( cd usr/lib ; rm -rf libltdl.so.7 )
( cd usr/lib ; ln -sf libltdl.so.7.3.0 libltdl.so.7 )
( cd usr/lib ; rm -rf libmenu.so.5 )
( cd usr/lib ; ln -sf libmenu.so.5.9 libmenu.so.5 )
( cd usr/lib ; rm -rf libldap.so )
( cd usr/lib ; ln -sf libldap-2.4.so.2.5.6 libldap.so )
( cd usr/lib ; rm -rf libpng.so.3 )
( cd usr/lib ; ln -sf libpng.so.3.44.0 libpng.so.3 )
( cd usr/lib ; rm -rf libgmpxx.so.4 )
( cd usr/lib ; ln -sf libgmpxx.so.4.2.1 libgmpxx.so.4 )
( cd usr/lib ; rm -rf libpng.so.14 )
( cd usr/lib ; ln -sf libpng14.so.14 libpng.so.14 )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2800.6 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libusb-1.0.so.0 )
( cd usr/lib ; ln -sf libusb-1.0.so.0.0.0 libusb-1.0.so.0 )
( cd usr/lib ; rm -rf libpng.so )
( cd usr/lib ; ln -sf libpng14.so libpng.so )
( cd usr/lib ; rm -rf libtalloc.so )
( cd usr/lib ; ln -sf libtalloc.so.2 libtalloc.so )
( cd usr/lib ; rm -rf libreadline.so )
( cd usr/lib ; ln -sf libreadline.so.5 libreadline.so )
( cd usr/lib ; rm -rf libpanelw.so.5 )
( cd usr/lib ; ln -sf libpanelw.so.5.9 libpanelw.so.5 )
( cd usr/lib ; rm -rf libltdl.so )
( cd usr/lib ; ln -sf libltdl.so.7.3.0 libltdl.so )
( cd usr/lib ; rm -rf libvga.so.1 )
( cd usr/lib ; ln -sf libvga.so.1.3.1 libvga.so.1 )
( cd usr/lib ; rm -rf libfreetype.so )
( cd usr/lib ; ln -sf libfreetype.so.6.6.2 libfreetype.so )
( cd usr/lib ; rm -rf libslang.so.1 )
( cd usr/lib ; ln -sf libslang.so.1.4.9 libslang.so.1 )
( cd usr/lib ; rm -rf libvga.so )
( cd usr/lib ; ln -sf libvga.so.1.3.1 libvga.so )
( cd usr/lib ; rm -rf libform.so.5 )
( cd usr/lib ; ln -sf libform.so.5.9 libform.so.5 )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2800.6 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libslang.so.2 )
( cd usr/lib ; ln -sf libslang.so.2.2.3 libslang.so.2 )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.2800.6 libgobject-2.0.so )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2800.6 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libelf.so.0 )
( cd usr/lib ; ln -sf libelf.so.0.8.13 libelf.so.0 )
( cd usr/lib ; rm -rf libtiff.so.3 )
( cd usr/lib ; ln -sf libtiff.so.3.9.4 libtiff.so.3 )
( cd usr/lib ; rm -rf libmm.so.14 )
( cd usr/lib ; ln -sf libmm.so.14.0.22 libmm.so.14 )
( cd usr/lib ; rm -rf libpng14.so.14 )
( cd usr/lib ; ln -sf libpng14.so.14.5.0 libpng14.so.14 )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.2800.6 libgthread-2.0.so )
( cd usr/lib ; rm -rf libmm.so )
( cd usr/lib ; ln -sf libmm.so.14.0.22 libmm.so )
( cd usr/lib ; rm -rf liblber-2.4.so.2 )
( cd usr/lib ; ln -sf liblber-2.4.so.2.5.6 liblber-2.4.so.2 )
( cd usr/lib ; rm -rf libpng12.so )
( cd usr/lib ; ln -sf libpng12.so.0.44.0 libpng12.so )
( cd usr/lib ; rm -rf libpcreposix.so )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so )
( cd usr/lib ; rm -rf libidn.so.11 )
( cd usr/lib ; ln -sf libidn.so.11.6.2 libidn.so.11 )
( cd usr/lib ; rm -rf libz.so.1 )
( cd usr/lib ; ln -sf libz.so.1.2.5 libz.so.1 )
( cd usr/lib ; rm -rf libexpat.so.1 )
( cd usr/lib ; ln -sf libexpat.so.1.5.2 libexpat.so.1 )
( cd usr/lib ; rm -rf libpng14.so )
( cd usr/lib ; ln -sf libpng14.so.14.5.0 libpng14.so )
( cd usr/lib ; rm -rf libformw.so.5 )
( cd usr/lib ; ln -sf libformw.so.5.9 libformw.so.5 )
( cd usr/lib ; rm -rf libtiff.so )
( cd usr/lib ; ln -sf libtiff.so.3.9.4 libtiff.so )
( cd usr/lib ; rm -rf libpanel.so.5 )
( cd usr/lib ; ln -sf libpanel.so.5.9 libpanel.so.5 )
( cd usr/lib ; rm -rf libreadline.so.5 )
( cd usr/lib ; ln -sf libreadline.so.5.2 libreadline.so.5 )
( cd usr/lib ; rm -rf libldap-2.4.so.2 )
( cd usr/lib ; ln -sf libldap-2.4.so.2.5.6 libldap-2.4.so.2 )
( cd usr/lib ; rm -rf libmp.so.3 )
( cd usr/lib ; ln -sf libmp.so.3.1.21 libmp.so.3 )
( cd usr/lib ; rm -rf libfreetype.so.6 )
( cd usr/lib ; ln -sf libfreetype.so.6.6.2 libfreetype.so.6 )
( cd usr/lib ; rm -rf libmp.so )
( cd usr/lib ; ln -sf libmp.so.3.1.21 libmp.so )
( cd usr/lib ; rm -rf libpng12.so.0 )
( cd usr/lib ; ln -sf libpng12.so.0.44.0 libpng12.so.0 )
( cd usr/lib ; rm -rf libgdbm.so.3 )
( cd usr/lib ; ln -sf libgdbm.so.3.0.0 libgdbm.so.3 )
( cd usr/lib ; rm -rf libmenu.so )
( cd usr/lib ; ln -sf libmenu.so.5 libmenu.so )
( cd usr/lib ; rm -rf libpcre.so.0 )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so.0 )
( cd usr/lib ; rm -rf libpcre.so )
( cd usr/lib ; ln -sf libpcre.so.0.0.1 libpcre.so )
( cd usr/lib ; rm -rf libasound.so.2 )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so.2 )
( cd usr/lib ; rm -rf libcups.so )
( cd usr/lib ; ln -sf libcups.so.2 libcups.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2800.6 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libgmpxx.so )
( cd usr/lib ; ln -sf libgmpxx.so.4.2.1 libgmpxx.so )
( cd usr/lib ; rm -rf libcurl.so )
( cd usr/lib ; ln -sf libcurl.so.4.2.0 libcurl.so )
( cd usr/lib ; rm -rf libmenuw.so )
( cd usr/lib ; ln -sf libmenuw.so.5 libmenuw.so )
( cd usr/lib ; rm -rf libz.so )
( cd usr/lib ; ln -sf libz.so.1.2.5 libz.so )
( cd usr/lib ; rm -rf libpanelw.so )
( cd usr/lib ; ln -sf libpanelw.so.5 libpanelw.so )
( cd usr/lib ; rm -rf libformw.so )
( cd usr/lib ; ln -sf libformw.so.5 libformw.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.2800.6 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.2800.6 libglib-2.0.so )
( cd usr/lib ; rm -rf libasound.so )
( cd usr/lib ; ln -sf libasound.so.2.0.0 libasound.so )
( cd usr/lib ; rm -rf liblber.so )
( cd usr/lib ; ln -sf liblber-2.4.so.2.5.6 liblber.so )
( cd usr/lib ; rm -rf libpcreposix.so.0 )
( cd usr/lib ; ln -sf libpcreposix.so.0.0.0 libpcreposix.so.0 )
( cd usr/lib ; rm -rf libidn.so )
( cd usr/lib ; ln -sf libidn.so.11.6.2 libidn.so )
( cd usr/lib ; rm -rf libusb-1.0.so )
( cd usr/lib ; ln -sf libusb-1.0.so.0.0.0 libusb-1.0.so )
( cd usr/lib ; rm -rf libhistory.so.5 )
( cd usr/lib ; ln -sf libhistory.so.5.2 libhistory.so.5 )
( cd usr/lib ; rm -rf libgmp.so )
( cd usr/lib ; ln -sf libgmp.so.10.0.1 libgmp.so )
( cd usr/lib ; rm -rf libmenuw.so.5 )
( cd usr/lib ; ln -sf libmenuw.so.5.9 libmenuw.so.5 )
( cd usr/lib ; rm -rf libform.so )
( cd usr/lib ; ln -sf libform.so.5 libform.so )
( cd usr/lib ; rm -rf libgmp.so.10 )
( cd usr/lib ; ln -sf libgmp.so.10.0.1 libgmp.so.10 )
( cd usr/lib ; rm -rf libldap_r-2.4.so.2 )
( cd usr/lib ; ln -sf libldap_r-2.4.so.2.5.6 libldap_r-2.4.so.2 )
( cd usr/lib ; rm -rf libusb.so )
( cd usr/lib ; ln -sf libusb-0.1.so.4.4.4 libusb.so )
( cd usr/lib ; rm -rf libvgagl.so )
( cd usr/lib ; ln -sf libvgagl.so.1.3.1 libvgagl.so )
( cd usr/lib ; rm -rf libusb-0.1.so.4 )
( cd usr/lib ; ln -sf libusb-0.1.so.4.4.4 libusb-0.1.so.4 )
( cd usr/lib ; rm -rf libslang.so )
( cd usr/lib ; ln -sf libslang.so.2.2.3 libslang.so )
( cd usr/lib ; rm -rf libjpeg.so )
( cd usr/lib ; ln -sf libjpeg.so.8.0.1 libjpeg.so )
( cd usr/lib ; rm -rf libgdbm.so )
( cd usr/lib ; ln -sf libgdbm.so.3.0.0 libgdbm.so )
( cd usr/lib ; rm -rf libldap_r.so )
( cd usr/lib ; ln -sf libldap_r-2.4.so.2.5.6 libldap_r.so )
( cd usr/lib ; rm -rf libvgagl.so.1 )
( cd usr/lib ; ln -sf libvgagl.so.1.3.1 libvgagl.so.1 )
( cd usr/lib ; rm -rf libjpeg.so.8 )
( cd usr/lib ; ln -sf libjpeg.so.8.0.1 libjpeg.so.8 )
( cd usr/lib ; rm -rf libpanel.so )
( cd usr/lib ; ln -sf libpanel.so.5 libpanel.so )
( cd usr/lib ; rm -rf libexpat.so )
( cd usr/lib ; ln -sf libexpat.so.1.5.2 libexpat.so )
( cd usr/lib ; rm -rf libelf.so )
( cd usr/lib ; ln -sf libelf.so.0.8.13 libelf.so )
( cd usr/lib ; rm -rf libcurl.so.4 )
( cd usr/lib ; ln -sf libcurl.so.4.2.0 libcurl.so.4 )
( cd usr/lib ; rm -rf libhistory.so )
( cd usr/lib ; ln -sf libhistory.so.5 libhistory.so )
( cd usr/lib ; rm -rf libcupsimage.so )
( cd usr/lib ; ln -sf libcupsimage.so.2 libcupsimage.so )
